@@ -1,3 +1,6 @@
+#' @include positron.R
+NULL
+
 #' @useDynLib torchpkg, .registration = TRUE
 #' @importFrom Rcpp sourceCpp
 NULL
@@ -12,6 +15,7 @@ globalVariables(c("..", "self", "private", "N"))
 
 .onLoad <- function(libname, pkgname) {
   register_s3_method("waldo", "compare_proxy", "torch_tensor")
+  register_positron_methods()
   cpp_torch_namespace__store_main_thread_id()
 
   install_success <- TRUE
