@@ -89,6 +89,10 @@ Tensor <- R7Class(
         dtype <- self$dtype
       }
 
+      if (is.null(memory_format)) {
+        memory_format <- torch_preserve_format()
+      }
+
       if (has_device) {
         private$`_to`(
           dtype = dtype,
@@ -504,6 +508,9 @@ tensor_to_complex <- function(x) {
 #'
 #' @export
 torch_tensor_from_buffer <- function(buffer, shape, dtype = "float") {
+  if (!is.integer(shape)) {
+    shape <- as.integer(shape)
+  }
   cpp_tensor_from_buffer(buffer, shape, list(dtype=dtype))
 }
 
